@@ -39,6 +39,18 @@ namespace KDcrawIface
 class LIBKDCRAW_EXPORT DcrawInfoContainer
 {
 
+public:
+
+    /** The RAW image orientation values
+     */
+    enum ImageOrientation
+    {
+        ORIENTATION_NONE  = 0,
+        ORIENTATION_180   = 3,
+        ORIENTATION_90CCW = 5,
+        ORIENTATION_90CW  = 6
+    };
+
 public:
 
     /** Standard constructor */
@@ -50,9 +62,12 @@ public:
         focalLength       = -1.0;
         pixelAspectRatio  = 1.0;    // Default value. This can be unavailable (depending of camera model).
         rawColors         = -1;
+        rawImages         = -1;
         hasIccProfile     = false;
         isDecodable       = false;
         hasSecondaryPixel = false;
+        blackPoint        = 0;
+        whitePoint        = 0;
         daylightMult[0]   = 0.0;
         daylightMult[1]   = 0.0;
         daylightMult[2]   = 0.0;
@@ -60,6 +75,7 @@ public:
         cameraMult[1]     = 0.0;
         cameraMult[2]     = 0.0;
         cameraMult[3]     = 0.0;
+        orientation       = ORIENTATION_NONE;
     };
 
     /** Standard destructor */
@@ -78,56 +94,86 @@ public:
              pixelAspectRatio == 1.0 &&
              sensitivity  == -1      && 
              rawColors    == -1      &&
+             rawImages    == -1      &&
+             blackPoint   == 0       &&
+             whitePoint   == 0       &&
              !dateTime.isValid()     && 
-             !imageSize.isValid() )
+             !imageSize.isValid()    &&
+             !fullSize.isValid()     &&
+             !outputSize.isValid()   &&
+             !thumbSize.isValid()    &&
+             orientation == ORIENTATION_NONE
+           )
             return true;
         else
             return false;
     };
 
     /** True if camera sensor use a secondary pixel. */
-    bool      hasSecondaryPixel;
+    bool             hasSecondaryPixel;
     /** True if RAW file include an ICC color profile. */
-    bool      hasIccProfile;
+    bool             hasIccProfile;
     /** True is RAW file is decodable by dcraw. */
-    bool      isDecodable;
+    bool             isDecodable;
 
     /** The number of RAW colors. */
-    int       rawColors;
+    int              rawColors;
+
+    /** The number of RAW images. */
+    int              rawImages;
+
+    /** Black level from Raw histogram. */
+    unsigned int     blackPoint;
+
+    /** White level from Raw histogram. */
+    unsigned int     whitePoint;
+
+    /** The raw image orientation */
+    ImageOrientation orientation;
 
     /** The sensitivity in ISO used by camera to take the picture. */
-    long      sensitivity;
+    long             sensitivity;
 
     /** ==> 1/exposureTime = exposure time in seconds. */
-    float     exposureTime;
+    float            exposureTime;
     /** ==> Aperture value in APEX. */
-    float     aperture;
+    float            aperture;
     /** ==> Focal Length value in mm. */
-    float     focalLength;
+    float            focalLength;
     /** The pixel Aspect Ratio if != 1.0. NOTE: if == 1.0, dcraw do not show this value. */
-    float     pixelAspectRatio;
+    float            pixelAspectRatio;
 
     /** White color balance settings. */
     double    daylightMult[3];
     /** Camera multipliers used for White Balance adjustements */
-    double    cameraMult[4];
+    double           cameraMult[4];
 
     /** The camera maker. */
-    QString   make;
+    QString          make;
     /** The camera model. */
-    QString   model;
+    QString          model;
     /** The artist name who have picture owner. */
-    QString   owner;
+    QString          owner;
     /** The demosaising filter pattern. */
-    QString   filterPattern;
+    QString          filterPattern;
     /** The DNG version. NOTE: its only show with DNG RAW files. */
-    QString   DNGVersion;
+    QString          DNGVersion;
 
     /** Date & time when have been taken the picture. */
     QDateTime dateTime;
 
+
     /** The image dimensions in pixels. */
-    QSize     imageSize;
+    QSize            imageSize;
+
+    /** The thumb dimensions in pixels. */
+    QSize            thumbSize;
+
+    /** The full RAW image dimensions in pixels. */
+    QSize            fullSize;
+
+    /** The output dimensions in pixels. */
+    QSize            outputSize;
 };
 
 } // namespace KDcrawIface
